==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/CreateSessionRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * CreateSessionRequest
 */
@JsonPropertyOrder({ CreateSessionRequest.JSON_PROPERTY_SESSION_TOKEN })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class CreateSessionRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SESSION_TOKEN = "sessionToken";
    private String sessionToken;

    public CreateSessionRequest() {
    }

    public CreateSessionRequest sessionToken(String sessionToken) {

        this.sessionToken = sessionToken;
        return this;
    }

    /**
     * The session token obtained during authentication
     *
     * @return sessionToken
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The session token obtained during authentication")
    @JsonProperty(JSON_PROPERTY_SESSION_TOKEN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getSessionToken() {
        return sessionToken;
    }

    @JsonProperty(JSON_PROPERTY_SESSION_TOKEN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSessionToken(String sessionToken) {
        this.sessionToken = sessionToken;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CreateSessionRequest createSessionRequest = (CreateSessionRequest) o;
        return Objects.equals(this.sessionToken, createSessionRequest.sessionToken);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(sessionToken);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CreateSessionRequest {\n");
        sb.append("    sessionToken: ").append(toIndentedString(sessionToken)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/CreateSessionRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * CreateSessionRequest
 */
@JsonPropertyOrder({ CreateSessionRequest.JSON_PROPERTY_SESSION_TOKEN })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class CreateSessionRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SESSION_TOKEN = "sessionToken";
    private String sessionToken;

    public CreateSessionRequest() {
    }

    public CreateSessionRequest sessionToken(String sessionToken) {

        this.sessionToken = sessionToken;
        return this;
    }

    /**
     * The session token obtained during authentication
     *
     * @return sessionToken
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The session token obtained during authentication")
    @JsonProperty(JSON_PROPERTY_SESSION_TOKEN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getSessionToken() {
        return sessionToken;
    }

    @JsonProperty(JSON_PROPERTY_SESSION_TOKEN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSessionToken(String sessionToken) {
        this.sessionToken = sessionToken;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CreateSessionRequest createSessionRequest = (CreateSessionRequest) o;
        return Objects.equals(this.sessionToken, createSessionRequest.sessionToken);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(sessionToken);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CreateSessionRequest {\n");
        sb.append("    sessionToken: ").append(toIndentedString(sessionToken)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
